@@ -1,7 +1,7 @@
 package Module::Faker::Package;
 use Moose;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose::Util::TypeConstraints;
 
@@ -9,8 +9,17 @@ has name     => (is => 'ro', isa => 'Str', required => 1);
 has version  => (is => 'ro', isa => 'Maybe[Str]');
 has abstract => (is => 'ro', isa => 'Maybe[Str]');
 
-# TODO: default this in from name -- rjbs, 2008-03-12
-has in_file => (is => 'ro', isa => 'Str', required => 1);
+has in_file  => (
+  is       => 'ro',
+  isa      => 'Str',
+  lazy     => 1,
+  default  => sub {
+    my ($self) = @_;
+    my $name = $self->name;
+    $name =~ s{::}{/}g;
+    return "lib/$name";
+  },
+);
 
 subtype 'Module::Faker::Type::Packages'
   => as 'ArrayRef[Module::Faker::Package]';
@@ -20,7 +29,13 @@ coerce 'Module::Faker::Type::Packages'
   => via  {
     my ($href) = @_;
     my @packages;
-    for my $name (keys %$href) {
+
+    my @pkg_names = do {
+      no warnings 'uninitialized';
+      sort { $href->{$a}{Faker}{order} <=> $href->{$b}{Faker}{order} } keys %$href;
+    };
+
+    for my $name (@pkg_names) {
       push @packages, __PACKAGE__->new({
         name    => $name,
         version => $href->{$name}{version},
